# TODO Please rename the filename from entity_constants.py to your entity. If your entity is country please change the file name to country_constants.py

from logger_local.LoggerComponentEnum import LoggerComponentEnum


# Please change everywhere there is "<Entity>" to your entity name i.e. "Country"  (Please pay attention the C is in uppercase)
# This is a class of all the constants of your entity
class LabelsLocalConstants:
    # TODO Please update your email
    DEVELOPER_EMAIL = 'tal.r@circ.zone'
    LABEL_MESSAGE_PACKAGE_COMPONENT_NAME = 'label_message_package'
    # TODO Please change everywhere in the code "LABEL_MESSAGE" to "COUNTRY_LOCAL_PYTHON" in case your entity is Country.
    # TODO Please send a message in the Slack to #request-to-open-component-id and get your COMPONENT_ID
    # For example COUNTRY_COMPONENT_ID = 34324
    LABEL_MESSAGE_PACKAGE_COMPONENT_ID = 254
    # TODO Please write your own COMPONENT_NAME
    LABEL_MESSAGE_COMPONENT_NAME = 'Country local Python package'
    LABEL_MESSAGE_CODE_LOGGER_OBJECT = {
        'component_id': LABEL_MESSAGE_PACKAGE_COMPONENT_ID,
        'component_name': LABEL_MESSAGE_PACKAGE_COMPONENT_NAME,
        'component_category': LoggerComponentEnum.ComponentCategory.Code.value,
        'developer_email': DEVELOPER_EMAIL
    }
    LABEL_MESSAGE_TEST_LOGGER_OBJECT = {
        'component_id': LABEL_MESSAGE_PACKAGE_COMPONENT_ID,
        'component_name': LABEL_MESSAGE_PACKAGE_COMPONENT_NAME,
        'component_category': LoggerComponentEnum.ComponentCategory.Unit_Test.value,
        # TODO Please add the framework you use
        'developer_email': DEVELOPER_EMAIL
    }
    MESSAGE_OUTBOX_LABEL_ID = 18



# TODO: This is an example file which you should delete after implementing
from circles_local_database_python.connector import Connector
from circles_local_database_python.generic_crud import GenericCRUD
from dotenv import load_dotenv
from logger_local.Logger import Logger
from logger_local.LoggerComponentEnum import LoggerComponentEnum

from .LabelConstants import LabelsLocalConstants

load_dotenv()

# Setup the logger: change YOUR_REPOSITORY variable name and value
YOUR_REPOSITORY_COMPONENT_ID = 0  # ask your team leader for this integer
YOUR_REPOSITORY_COMPONENT_NAME = "Enter you repository name"
DEVELOPER_EMAIL = "Enter you circlez.ai email"
object1 = {
    'component_id': YOUR_REPOSITORY_COMPONENT_ID,
    'component_name': YOUR_REPOSITORY_COMPONENT_NAME,
    'component_category': LoggerComponentEnum.ComponentCategory.Code.value,
    'developer_email': DEVELOPER_EMAIL
}
logger = Logger.create_logger(object=object1)


class LabelsMessageLocal(GenericCRUD):

    def __init__(self):
        super().__init__(default_schema_name="label_message", default_table_name="label_message_table",
                         default_view_table_name='label_message_view')

    def add_label(self, label_id: int, message_id: int):
        label_data = {
            "label_id": label_id,
            "message_id": message_id
        }
        label_message_id = self.insert(data_json=label_data)
        return label_message_id



import setuptools

# Each Python project should have pyproject.toml or setup.py (if both exist, we use the setup.py)
# TODO: Please create pyproject.toml instead of setup.py (delete the setup.py)
# used by python -m build
# ```python -m build``` needs pyproject.toml or setup.py
# The need for setup.py is changing as of poetry 1.1.0 (including current pre-release) as we have moved away
#  from needing to generate a setup.py file to enable editable installs - We might able to delete this file
#  in the near future

# TODO: Change the PACKAGE_NAME to the name of the package - Either xxx-local or xxx-remote
#   (without the -python-package suffix)
PACKAGE_NAME = "label-message-local"
# Since all PACAKGE_NAMEs are with an underscore, we don't need this. Why do we need it?
package_dir = PACKAGE_NAME.replace("-", "_")

setuptools.setup(
    # TODO: Please update the name and delete this line i.e. XXX-local or XXX-remote
    #  (without the -python-package suffix). Only lowercase, no underlines.
    name=PACKAGE_NAME,
    version='0.0.2',  # update only the minor version each time # https://pypi.org/project/<short-project-name-with-underscores>/
    author="Circles",
    author_email="info@circlez.ai",
    # TODO: Please update the description and long_description with no sensitive information as it is exposed in pypi.org
    description="PyPI Package for Circles <short-project-name-with-dash> Python",
    long_description="PyPI Package for Circles <short-project-name-with-dash> Python",
    long_description_content_type='text/markdown',
    # TODO: Please update the URL below
    url="https://github.com/circles",  # https://pypi.org/project/<project-name>/
    # packages=setuptools.find_packages(),
    packages=[package_dir],
    package_dir={package_dir: f'{package_dir}/src'},
    package_data={package_dir: ['*.py']},
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: Other/Proprietary License",
        "Operating System :: OS Independent",
    ],
    # TODO: Update which packages to include with this package
    install_requires=[
        'PyMySQL>=1.0.2',
        'pytest>=7.4.0',
        'mysql-connector>=2.2.9',
        'logzio-python-handler>= 4.1.0',
        'user-context-remote>=0.0.17',
        'python-sdk-local>=0.0.27'
    ],
)
